mix localize.translate.gen.translate_function (Localize Translate v0.1.0)

Copy Markdown View Source

Generates a migration to add a database function translate_field that uses the Localize.Translate structured translation schema to resolve a translation for a field.

Summary

Functions

format_string!(string)

@spec format_string!(String.t()) :: iodata()

migrations_path(repo)